@@ -22,12 +22,19 @@ function http_post_data($url, $data_string) {
 $type=$argv[1];
 //echo $type;
 $id=$argv[2];
+echo "send json start in php\n";
 
-if(!$id || ($type!="send" && $type!="recv")) exit;
+if(!$id || ($type!="send" && $type!="recv")) {
+	echo "no ID or on Type exit php\n";
+	exit;
+}
 if($type=="send"){
 	$query=$db->query("select json_send_url from system");
 	$rs=$db->fetch_array($query);
-	if(!$rs[0]) exit;
+	if(!$rs[0]) {
+		echo "no URL exit php\n";
+		exit;
+	}
 	
 	$url=$rs[0];
 	$query=$db->query("select * from sends left join goip on goip.id=goipid where sends.id='$id' order by sends.id");
@@ -61,7 +68,10 @@ if($type=="send"){
 }else if($type=="recv"){
 	$query=$db->query("select json_recv_url from system");
 	$rs=$db->fetch_array($query);
-	if(!$rs[0]) exit;
+	if(!$rs[0]) {
+		echo "no ID or on Type exit php\n";
+		exit;
+	}
 	$url=$rs[0];
 	$query=$db->query("select * from receive left join goip on goip.id=goipid where receive.id='$id'");
 	if($row=$db->fetch_array($query)){
@@ -75,5 +85,6 @@ if($type=="send"){
 		echo "\n";
 	}
 }
+echo "send json end in php\n";
 
 ?>
